#' Translation for internationalisation
#'
#' @param x Expression to translate in English
#' @param lang Language to translate (to choose among supported language by LaTeX babel package)
#' @param translation_table TSV file where translations are stored, on row by expression, on column by language
#' @param silent If the translation is not found returns the non-translated expression silently, otherwise it throws an error
#'
#' @return The translated expression.
#' @export
#'
#' @examples
#' i18n("chapter", "french")
i18n <- function(x, lang = getOption("lang", "english"), translation_table = pkg_sys("i18n.tsv"), silent = TRUE) {
  if (lang== "english") return(x)
  df <- readr::read_tsv(translation_table, show_col_types = FALSE)
  if (!lang %in% names(df)) {
    stop("Language \"", lang,"\" not found in translation table: ", translation_table)
  }
  i <- which(df$english == x)
  if (length(i) == 0) {
    if(silent) return (x)
    stop("Translations of expression \"", x, "\" not found")
  }
  if (length(i) != 1) {
    stop("More than one thanslation of \"", x, "\" has been found.\n",
         "Please correct the translation table: ", translation_table)
  }
  return(df[i, lang])
}

#' Check if a language is supported by LaTeX babel package
#'
#' @inheritParams i18n
#'
#' @return A [logical]
#' @export
#'
#' @examples
#' i18n_lang_exists("french")
#'
i18n_lang_exists <- function(lang = "english") {
  curl::curl_fetch_memory(paste0("https://ctan.org/pkg/babel-", lang))$status_code != 404
}
